@@ -19,13 +19,15 @@
 # 02110-1301, USA.
 
 import os
+import urllib
 import urllib2
 import tempfile
 import shutil
 
 class TagFile:
-    def __init__(self, mirrors, source_mirrors=None):
+    def __init__(self, mirrors, source_mirrors=None, installer_packages=True):
         self.mirrors = mirrors
+        self.installer_packages = installer_packages
         if source_mirrors:
             self.source_mirrors = source_mirrors
         else:
@@ -41,7 +43,8 @@ class TagFile:
             filename = None
 
             if req.get_type() != "file":
-                filename = "%s_%s_%s_%s" % (req.get_host(), dist, component, tagfile_type)
+                filename = "%s_%s_%s_%s" % (urllib.quote(mirror, safe=""), dist,
+                                            component, tagfile_type)
             else:
                 # Make a more or less dummy filename for local URLs.
                 filename = os.path.split(req.get_selector())[0].replace(os.sep, "_")
@@ -127,16 +130,17 @@ class TagFile:
                         "source/Sources"))
 
                 instpackages = ""
-                try:
-                    instpackages = self.open_tag_files(
-                        self.mirrors, dirname, "InstallerPackages", dist, component,
-                        "debian-installer/binary-" + arch + "/Packages")
-                except IOError:
-                    # can live without these
-                    print "Missing installer Packages file for", component, \
-                          "(ignoring)"
-                else:
-                    g.parsePackages(instpackages, "udeb")
+                if self.installer_packages:
+                    try:
+                        instpackages = self.open_tag_files(
+                            self.mirrors, dirname, "InstallerPackages", dist, component,
+                            "debian-installer/binary-" + arch + "/Packages")
+                    except IOError:
+                        # can live without these
+                        print "Missing installer Packages file for", component, \
+                              "(ignoring)"
+                    else:
+                        g.parsePackages(instpackages, "udeb")
 
         if cleanup:
             shutil.rmtree(dirname)
