@@ -34,9 +34,9 @@ import Germinate.version
 
 # TODO: cloned from germinate.py; should be common
 SEEDS = ["http://people.canonical.com/~ubuntu-archive/seeds/"]
-RELEASE = "ubuntu.natty"
+RELEASE = "ubuntu.oneiric"
 MIRRORS = ["http://archive.ubuntu.com/ubuntu/"]
-DIST = ["natty"]
+DIST = ["oneiric"]
 COMPONENTS = ["main"]
 ARCH = "i386"
 
